#
# spec file for package python-Pebble
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-Pebble
Version:        5.1.0
Release:        1.3
Summary:        Threading and multiprocessing eye-candy for Python
License:        LGPL-3.0-only
URL:            https://github.com/noxdafox/pebble
Source:         https://files.pythonhosted.org/packages/source/P/Pebble/Pebble-%{version}.tar.gz
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  git-core
BuildRequires:  python-rpm-macros
BuildRequires:  python3-base >= 3.7
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module pytest}
# /SECTION
%python_subpackages

%description
Pebble provides an API to manage threads and processes within an application.
It wraps Python’s standard library threading and multiprocessing objects.

%prep
%setup -q -n Pebble-%{version}

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%files %{python_files}
%doc README.rst
%license LICENSE
%{python_sitelib}/pebble
%{python_sitelib}/Pebble-%{version}*

%changelog
* Fri Jan 24 2025 Yunus Acar <yunus.acar@suse.com>
- Update to 5.1.0:
  * issue #140: expose internal constants to allow changing default
    timeouts and polling intervals.
  * issue #141: add PID of expired process to ProcessExpired exception.
  * Add pool decorators parameter allowing to provide a PebblePool
    as executor for the decorated functions.
  * issue #137: reset SIGTERM default handler to child processes.
  * Include concurrent and asynchronous modules as top-level packages.
  * Improve type hinting logic.
  * Refactor internal logic: remove code duplication.
* Fri Mar 22 2024 Dirk Müller <dmueller@suse.com>
- update to 5.0.7:
  * issue #96: handle race condition under different interpreters
  * issue #125: handle frozen classes as exceptions
  * issue #127: handle unexpected errors when reading from pipe in
    process decorators
  * issue #128: allow different context from `multiprocessing` ones
* Wed Dec 27 2023 Dirk Müller <dmueller@suse.com>
- update to 5.0.6:
  * issue #124: handle `BaseException` in pools' workers
* Sun Dec 10 2023 Dirk Müller <dmueller@suse.com>
- update to 5.0.5:
  * issue #123: do not raise exception when returned from workers
  * issue #122: slightly improve type hints
  * issue #122: add type hints to decorator functions
* Tue Nov 15 2022 Martin Liška <mliska@suse.cz>
- Update to 5.0.3
  * issue #111: reinstate `Pool.schedule` function in place of
    `Pool.submit`.
* Mon Oct 10 2022 Martin Liška <mliska@suse.cz>
- Update to 5.0.2
  * issue #108: fix build tag enforcing Python 3.6 as minimum
  compatible version.
* Thu Oct  6 2022 Martin Liška <mliska@suse.cz>
- Update to 5.0.1
  * Improvements:
  + issue #105: run callbacks after process termination on timeout or
    task cancellation
* Tue Sep 13 2022 Martin Liška <mliska@suse.cz>
- Update to 5.0.0
  * Backward incompatible changes:
  + issue #93: Python 2 is no longer compatible. Minimum supported
    version is now 3.7.
  * Deprecations:
  + issue #90: pools `schedule` method is now deprecated, use `submit`
    instead.
  * Features:
  + issue #90: pools are now compatible with asyncio APIs.
  + issue #94: asynchronous function decorators
  + issue #102: type hints have been added to all functionalities
  + issue #103: support alternative multiprocessing.context
    implementations
  * Fixes:
  + issue #99: fix deadlock when closing a full pipe on Windows in pool
- Require Python >= 3.7.
- Drop Python 2 support.
* Tue Aug 16 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to 4.6.3
  + issue #84: fix import bug on Windows
- Update to 4.6.2
  * Fixes:
  + issue #82: fix issue with poll mechanism in MAC OS Mojave (@sam-harding)
  + Fix polling timeout resolution (@sam-harding)
- Update to 4.6.1
  * Improvements:
  + issue #76: allow spawning processes within `ProcessPool` workers
  + Few minor improvements
  * Fixes:
  + issues #75: fix error when cancelling futures in Python >= 3.8
  + issue #80: fix error when using decorators without @pie notation
  + Several minor fixes on MAC OS
  * Tests:
  + Add Windows and MAC OS test automation support
* Thu Jan 14 2021 Steve Kowalik <steven.kowalik@suse.com>
- Update to 4.6.0
  * Features:
    + issue #73: allow passing `multiprocessing.context` object
    as `concurrent.process` and `ProcessPool` parameter
  * Fixes:
    + issues #34, #35: rework Pool termination logic to silence Windows errors
    + issue #68: use fully qualified function name in `concurrent.process`
    decorator trampoline to handle class inheritance in Windows
    + issue #69: correctly propagate the timeout in pool's map method
    + issue #64: rework versioning logic
* Wed May  6 2020 Martin Liška <mliska@suse.cz>
- Bump to 4.5.2:
  - Fix issue #58: handle pool connection teardown in Python 3.8
* Mon Apr 20 2020 Tomáš Chvátal <tchvatal@suse.com>
- Fix build without python2
* Thu Mar 26 2020 Marketa Calabkova <mcalabkova@suse.com>
- update to 4.5.1
  * add daemon parameter to decorator
  * travis: add Python 3.8 tests
* Wed Jan 15 2020 Marketa Calabkova <mcalabkova@suse.com>
- update to 4.4.1
  * use poll in channel implementation instead of select
  * handle pickling errors in ProcessPool
  * add test cases
* Mon Oct  7 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 4.4.0:
  * Various doc and test fixes
* Sat Aug 24 2019 Jan Engelhardt <jengelh@inai.de>
- Use description from upstream.
* Sun Aug 11 2019 Todd R <toddrme2178@gmail.com>
- Initial version
